@@ -46,6 +46,10 @@ class Model:
                 gens = rearrangements.all_inversions_representatives(framework)
                 for generator in gens:
                     model[generator] = relative_prob/len(gens)
+            if model_name is MODEL.two_region_adjacent_transpositions:
+                gens = rearrangements.all_adjacent_transpositions_representatives(framework, num_regions=2)
+                for generator in gens:
+                    model[generator] = relative_prob/len(gens)
         model = cls(framework, model)
         model.names += list(named_model_dictionary.keys())
         return model
