@@ -5,12 +5,12 @@ import pytest
 def example_framework():
     yield example()
 
-def test_one_row_and_cycles(example_framework):
+def test_one_row_and_cycles_random(example_framework):
     fw, model = example_framework
     instance = fw.random_instance()
     assert instance == fw.cycles(fw.one_row(instance))
 
-def test_matrix_and_cycles(example_framework):
+def test_matrix_and_cycles_random(example_framework):
     fw, model = example_framework
     instance = fw.random_instance()
     assert instance == fw.cycles(fw.matrix(instance))
\ No newline at end of file
